summaryrefslogtreecommitdiffhomepage
path: root/examples
diff options
context:
space:
mode:
authorRay <[email protected]>2021-07-23 18:16:08 +0200
committerRay <[email protected]>2021-07-23 18:16:08 +0200
commit0fa295c72ddaff928dc883bb29b785d8be063154 (patch)
treed3a2d010d36ccac4ec37a76bec06d571705296a2 /examples
parent4a01139c8d87584b7d62a2c7d60b151d6be5ee9c (diff)
downloadraylib-0fa295c72ddaff928dc883bb29b785d8be063154.tar.gz
raylib-0fa295c72ddaff928dc883bb29b785d8be063154.zip
Review formating to follow raylib style conventions
Diffstat (limited to 'examples')
-rw-r--r--examples/shaders/shaders_shapes_outline.c32
1 files changed, 16 insertions, 16 deletions
diff --git a/examples/shaders/shaders_shapes_outline.c b/examples/shaders/shaders_shapes_outline.c
index 591feb6a..d70f7645 100644
--- a/examples/shaders/shaders_shapes_outline.c
+++ b/examples/shaders/shaders_shapes_outline.c
@@ -1,7 +1,7 @@
/*******************************************************************************************
*
* raylib [shaders] example - Apply an outline to a texture
*
* NOTE: This example requires raylib OpenGL 3.3 or ES2 versions for shaders support,
* OpenGL 1.1 does not support shaders, recompile raylib to OpenGL 3.3 version.
*
@@ -31,15 +31,15 @@ int main(void)
const int screenWidth = 800;
const int screenHeight = 450;
- InitWindow(screenWidth, screenHeight, "raylib [shaders] example - Apply an outline to a texture");
+ InitWindow(screenWidth, screenHeight, "raylib [shaders] example - Apply an shdrOutline to a texture");
- Texture2D egg = LoadTexture("resources/egg.png");
- Texture2D torus = LoadTexture("resources/torus.png");
- Shader outline = LoadShader(0, TextFormat("resources/shaders/glsl%i/outline.fs", GLSL_VERSION));
+ Texture2D egg = LoadTexture("resources/egg.png");
+ Texture2D torus = LoadTexture("resources/torus.png");
+ Shader shdrOutline = LoadShader(0, TextFormat("resources/shaders/glsl%i/shdrOutline.fs", GLSL_VERSION));
- float oScale = 16.0;
- float tScale[2] = { 16.0f*4, 16.0f*4 };
- SetShaderValue(outline, GetShaderLocation(outline, "texScale"), tScale, SHADER_UNIFORM_VEC2);
+ float outlineScale = 16.0f;
+ float textureScale[2] = { 16.0f*4, 16.0f*4 };
+ SetShaderValue(shdrOutline, GetShaderLocation(shdrOutline, "texScale"), textureScale, SHADER_UNIFORM_VEC2);
SetTargetFPS(60); // Set our game to run at 60 frames-per-second
//--------------------------------------------------------------------------------------
@@ -58,12 +58,12 @@ int main(void)
ClearBackground(RAYWHITE);
- BeginShaderMode(outline);
- DrawTextureEx(egg, (Vector2){ 0, 230 }, 0.0, oScale, WHITE);
- DrawTextureEx(torus, (Vector2){ 544, 230 }, 0.0, oScale, WHITE);
+ BeginShaderMode(shdrOutline);
+ DrawTextureEx(egg, (Vector2){ 0, 230 }, 0.0, outlineScale, WHITE);
+ DrawTextureEx(torus, (Vector2){ 544, 230 }, 0.0, outlineScale, WHITE);
EndShaderMode();
- DrawText("Shader-based outlines for textures", 190, 200, 20, LIGHTGRAY);
+ DrawText("Shader-based shdrOutlines for textures", 190, 200, 20, LIGHTGRAY);
DrawFPS(710, 10);
@@ -73,9 +73,9 @@ int main(void)
// De-Initialization
//--------------------------------------------------------------------------------------
- UnloadTexture(egg);
- UnloadTexture(torus);
- UnloadShader(outline);
+ UnloadTexture(egg);
+ UnloadTexture(torus);
+ UnloadShader(shdrOutline);
CloseWindow(); // Close window and OpenGL context
//--------------------------------------------------------------------------------------
@@ -1,7 +1,7 @@
/*******************************************************************************************
*
-* raylib [shaders] example - Apply an outline to a texture
-*
+* raylib [shaders] example - Apply an shdrOutline to a texture
+*
* NOTE: This example requires raylib OpenGL 3.3 or ES2 versions for shaders support,
* OpenGL 1.1 does not support shaders, recompile raylib to OpenGL 3.3 version.